
// Workaround to access protected functions
#ifndef protected
#  define protected public
#endif

// default includes
#include <shiboken.h>
#include <sbkpep.h>
#include <sbkpepbuffer.h>

#define PYSIDE6_COMOPT_COMPRESS 1

#ifndef QT_NO_VERSION_TAGGING
#  define QT_NO_VERSION_TAGGING
#endif
#include <QtCore/QDebug>
#include <pysideqenum.h>
#include <pysideutils.h>
#include <feature_select.h>
QT_WARNING_DISABLE_DEPRECATED


// module include
#include "kcalendarcore_python.h"

// main header
#include "kcalendarcore_incidencebase_wrapper.h"

// Wrappers providing overrides
#include "kcalendarcore_incidencebase_wrapper.h"
#include "kcalendarcore_customproperties_wrapper.h"

// inner classes
#include "kcalendarcore_incidencebase_incidenceobserver_wrapper.h"

// Argument includes
#include <QList>
#include <QSet>
#include <QString>
#include <QStringList>
#include <QtCore/qlatin1stringview.h>
#include <attendee.h>
#include <duration.h>
#include <incidencebase.h>
#include <person.h>
#include <qbytearray.h>
#include <qdatastream.h>
#include <qdatetime.h>
#include <qobject.h>
#include <qobjectdefs.h>
#include <qtimezone.h>
#include <qurl.h>

#include <cctype>
#include <cstring>
#include <iterator>
#include <type_traits>
#include <typeinfo>

using namespace KCalendarCore;

extern "C" {
static PyTypeObject *Sbk_KCalendarCore_IncidenceBase_TypeF(void)
{
    return SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX].type;
}
} // extern "C"

// Native ---------------------------------------------------------

void IncidenceBaseWrapper::resetPyMethodCache()
{
    std::fill(m_PyMethodCache.begin(), m_PyMethodCache.end(), nullptr);
}

void IncidenceBaseWrapper::customPropertyUpdate()
{
    static const char *funcName = "customPropertyUpdate";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[0], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdate();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("IncidenceBase", funcName, gil, pyOverride);
}

void IncidenceBaseWrapper::customPropertyUpdated()
{
    static const char *funcName = "customPropertyUpdated";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[1], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::customPropertyUpdated();
    }
    CustomPropertiesWrapper::sbk_o_customPropertyUpdate("IncidenceBase", funcName, gil, pyOverride);
}

::QDateTime IncidenceBaseWrapper::dateTime(::KCalendarCore::IncidenceBase::DateTimeRole role) const
{
    static const char *funcName = "dateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[2], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.dateTime");
        return {};
    }
    return sbk_o_dateTime("IncidenceBase", funcName, gil, pyOverride, role);
}

::QDateTime IncidenceBaseWrapper::sbk_o_dateTime([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] ::KCalendarCore::IncidenceBase::DateTimeRole role)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), &role)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), &role)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< QDateTime >()), Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QDateTime cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void IncidenceBaseWrapper::deserialize(::QDataStream & in)
{
    static const char *funcName = "deserialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[3], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::deserialize(in);
    }
    sbk_o_deserialize("IncidenceBase", funcName, gil, pyOverride, in);
}

void IncidenceBaseWrapper::sbk_o_deserialize([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] ::QDataStream & in)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &in)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), &in)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

::QDateTime IncidenceBaseWrapper::dtStart() const
{
    // This method belongs to a property.
    static const char *funcName = "1:dtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[4], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::dtStart();
    }
    return sbk_o_dtStart("IncidenceBase", funcName, gil, pyOverride);
}

::QDateTime IncidenceBaseWrapper::sbk_o_dtStart([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< QDateTime >()), Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QDateTime cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

bool IncidenceBaseWrapper::equals(const ::KCalendarCore::IncidenceBase & incidenceBase) const
{
    static const char *funcName = "equals";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[5], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::equals(incidenceBase);
    }
    return sbk_o_equals("IncidenceBase", funcName, gil, pyOverride, incidenceBase);
}

bool IncidenceBaseWrapper::sbk_o_equals([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::KCalendarCore::IncidenceBase & incidenceBase)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), &incidenceBase)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::referenceToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), &incidenceBase)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return false;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "bool", Py_TYPE(pyResult)->tp_name);
        return false;
    }
    bool cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QLatin1String IncidenceBaseWrapper::mimeType() const
{
    static const char *funcName = "mimeType";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[6], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.mimeType");
        return ::QLatin1String();
    }
    return sbk_o_mimeType("IncidenceBase", funcName, gil, pyOverride);
}

::QLatin1String IncidenceBaseWrapper::sbk_o_mimeType([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return ::QLatin1String();
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, "QLatin1String", Py_TYPE(pyResult)->tp_name);
        return ::QLatin1String();
    }
    ::QLatin1String cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QDateTime IncidenceBaseWrapper::recurrenceId() const
{
    static const char *funcName = "recurrenceId";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[7], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::recurrenceId();
    }
    return IncidenceBaseWrapper::sbk_o_dtStart("IncidenceBase", funcName, gil, pyOverride);
}

void IncidenceBaseWrapper::serialize(::QDataStream & out) const
{
    static const char *funcName = "serialize";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[8], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::serialize(out);
    }
    IncidenceBaseWrapper::sbk_o_deserialize("IncidenceBase", funcName, gil, pyOverride, out);
}

void IncidenceBaseWrapper::setAllDay(bool allDay)
{
    // This method belongs to a property.
    static const char *funcName = "2:setAllDay";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[9], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setAllDay(allDay);
    }
    sbk_o_setAllDay("IncidenceBase", funcName, gil, pyOverride, allDay);
}

void IncidenceBaseWrapper::sbk_o_setAllDay([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] bool allDay)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &allDay)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &allDay)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void IncidenceBaseWrapper::setDateTime(const ::QDateTime & dateTime, ::KCalendarCore::IncidenceBase::DateTimeRole role)
{
    static const char *funcName = "setDateTime";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[10], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.setDateTime");
        return;
    }
    sbk_o_setDateTime("IncidenceBase", funcName, gil, pyOverride, dateTime, role);
}

void IncidenceBaseWrapper::sbk_o_setDateTime([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QDateTime & dateTime, [[maybe_unused]] ::KCalendarCore::IncidenceBase::DateTimeRole role)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &dateTime),
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), &role)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &dateTime),
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), &role)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void IncidenceBaseWrapper::setDtStart(const ::QDateTime & dtStart)
{
    // This method belongs to a property.
    static const char *funcName = "2:setDtStart";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[11], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setDtStart(dtStart);
    }
    sbk_o_setDtStart("IncidenceBase", funcName, gil, pyOverride, dtStart);
}

void IncidenceBaseWrapper::sbk_o_setDtStart([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QDateTime & dtStart)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &dtStart)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &dtStart)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void IncidenceBaseWrapper::setDuration(const ::KCalendarCore::Duration & duration)
{
    static const char *funcName = "setDuration";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[12], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setDuration(duration);
    }
    sbk_o_setDuration("IncidenceBase", funcName, gil, pyOverride, duration);
}

void IncidenceBaseWrapper::sbk_o_setDuration([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::KCalendarCore::Duration & duration)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[1] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Duration_IDX]), &duration)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(N)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Duration_IDX]), &duration)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 1, nullptr));
    Py_DECREF(pyArgArray[0]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

void IncidenceBaseWrapper::setLastModified(const ::QDateTime & lm)
{
    // This method belongs to a property.
    static const char *funcName = "2:setLastModified";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[13], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setLastModified(lm);
    }
    IncidenceBaseWrapper::sbk_o_setDtStart("IncidenceBase", funcName, gil, pyOverride, lm);
}

void IncidenceBaseWrapper::setReadOnly(bool readOnly)
{
    static const char *funcName = "setReadOnly";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[14], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::setReadOnly(readOnly);
    }
    IncidenceBaseWrapper::sbk_o_setAllDay("IncidenceBase", funcName, gil, pyOverride, readOnly);
}

void IncidenceBaseWrapper::shiftTimes(const ::QTimeZone & oldZone, const ::QTimeZone & newZone)
{
    static const char *funcName = "shiftTimes";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[15], nameCache));
    if (pyOverride.isNull()) {
        return this->::KCalendarCore::IncidenceBase::shiftTimes(oldZone, newZone);
    }
    sbk_o_shiftTimes("IncidenceBase", funcName, gil, pyOverride, oldZone, newZone);
}

void IncidenceBaseWrapper::sbk_o_shiftTimes([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] const ::QTimeZone & oldZone, [[maybe_unused]] const ::QTimeZone & newZone)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &oldZone),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &newZone)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &oldZone),
        Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), &newZone)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

::KCalendarCore::IncidenceBase::IncidenceType IncidenceBaseWrapper::type() const
{
    static const char *funcName = "type";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[16], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.type");
        return KCalendarCore::IncidenceBase::TypeEvent;
    }
    return sbk_o_type("IncidenceBase", funcName, gil, pyOverride);
}

::KCalendarCore::IncidenceBase::IncidenceType IncidenceBaseWrapper::sbk_o_type([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return KCalendarCore::IncidenceBase::TypeEvent;
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceType_IDX]))), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< KCalendarCore::IncidenceBase::IncidenceType >()), Py_TYPE(pyResult)->tp_name);
        return KCalendarCore::IncidenceBase::TypeEvent;
    }
    ::KCalendarCore::IncidenceBase::IncidenceType cppResult{KCalendarCore::IncidenceBase::TypeEvent};
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

::QByteArray IncidenceBaseWrapper::typeStr() const
{
    static const char *funcName = "typeStr";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[17], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.typeStr");
        return {};
    }
    return sbk_o_typeStr("IncidenceBase", funcName, gil, pyOverride);
}

::QByteArray IncidenceBaseWrapper::sbk_o_typeStr([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride)
{
#if defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyArgs(PyTuple_New(0));
#endif

#if !defined(PYPY_VERSION)
    Shiboken::AutoDecRef pyResult(PyObject_CallNoArgs(pyOverride));
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return {};
    }
    // Check return type
    Shiboken::Conversions::PythonToCppConversion pythonToCpp =
        Shiboken::Conversions::pythonToCppValueConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), pyResult);
    if (!pythonToCpp) {
        Shiboken::Warnings::warnInvalidReturnValue(ownerClassName, funcName, PepType_GetFullyQualifiedNameStr(Shiboken::SbkType< QByteArray >()), Py_TYPE(pyResult)->tp_name);
        return {};
    }
    ::QByteArray cppResult;
    pythonToCpp(pyResult, &cppResult);
    return cppResult;
}

void IncidenceBaseWrapper::virtual_hook(::KCalendarCore::IncidenceBase::VirtualHook id, void * data)
{
    static const char *funcName = "virtual_hook";
    static PyObject *nameCache[2] = {};
    Shiboken::GilState gil(false);
    Shiboken::AutoDecRef pyOverride(Sbk_GetPyOverride(this, Sbk_KCalendarCore_IncidenceBase_TypeF(), gil, funcName, m_PyMethodCache[18], nameCache));
    if (pyOverride.isNull()) {
        gil.acquire();
        Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.virtual_hook");
        return;
    }
    sbk_o_virtual_hook("IncidenceBase", funcName, gil, pyOverride, id, data);
}

void IncidenceBaseWrapper::sbk_o_virtual_hook([[maybe_unused]] const char *ownerClassName, [[maybe_unused]] const char *funcName, [[maybe_unused]] Shiboken::GilState &gil, [[maybe_unused]] const Shiboken::AutoDecRef &pyOverride, [[maybe_unused]] ::KCalendarCore::IncidenceBase::VirtualHook id, [[maybe_unused]] void * data)
{
#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    PyObject *pyArgArray[2] = {
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_VirtualHook_IDX]))), &id),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), data)
    };
#else
    Shiboken::AutoDecRef pyArgs(Py_BuildValue("(NN)",
        Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_VirtualHook_IDX]))), &id),
        Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), data)
    ));
#endif

#if !defined(PYPY_VERSION) && (!defined(Py_LIMITED_API) || Py_LIMITED_API >= 0x030C0000)
    Shiboken::AutoDecRef pyResult(PyObject_Vectorcall(pyOverride, pyArgArray, 2, nullptr));
    Py_DECREF(pyArgArray[0]);
    Py_DECREF(pyArgArray[1]);
#else
    Shiboken::AutoDecRef pyResult(PyObject_Call(pyOverride, pyArgs, nullptr));
#endif
    if (pyResult.isNull()) {
        // An error happened in python code!
        Shiboken::Errors::storePythonOverrideErrorOrPrint(ownerClassName, funcName);
        return;
    }
}

IncidenceBaseWrapper::~IncidenceBaseWrapper()
{
    auto *wrapper = Shiboken::BindingManager::instance().retrieveWrapper(this, Sbk_KCalendarCore_IncidenceBase_TypeF());
    Shiboken::Object::destroy(wrapper, this);
}

// Target ---------------------------------------------------------

extern "C" {
static int Sbk_KCalendarCore_IncidenceBase_Init(PyObject *, PyObject *, PyObject *)
{
    Shiboken::Errors::setInstantiateNonConstructible("IncidenceBase");
    return -1;
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_addAttendee(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "addAttendee", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    if (PyArg_ParseTuple(args, "|OO:addAttendee", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::addAttendee(const KCalendarCore::Attendee&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // addAttendee(KCalendarCore::Attendee,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // IncidenceBase::addAttendee(const KCalendarCore::Attendee&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "addAttendee", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"doUpdate", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "addAttendee", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);
            }
        }
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::KCalendarCore::Attendee cppArg0_local;
        ::KCalendarCore::Attendee *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::addAttendee(const KCalendarCore::Attendee&,bool=)
            cppSelf->addAttendee(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_addComment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::addComment(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // IncidenceBase::addComment(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addComment", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::addComment(const QString&)
            cppSelf->addComment(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_addContact(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::addContact(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // IncidenceBase::addContact(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "addContact", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::addContact(const QString&)
            cppSelf->addContact(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_allDay(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::allDay()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->allDay();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_attendeeByMail(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::attendeeByMail(const QString&)const->KCalendarCore::Attendee
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // IncidenceBase::attendeeByMail(const QString&)const->KCalendarCore::Attendee
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "attendeeByMail", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::attendeeByMail(const QString&)const->KCalendarCore::Attendee
            KCalendarCore::Attendee cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->attendeeByMail(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_attendeeByMails(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "attendeeByMails", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    if (PyArg_ParseTuple(args, "|OO:attendeeByMails", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::attendeeByMails(const QStringList&,const QString&=)const->KCalendarCore::Attendee
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // attendeeByMails(QStringList,QString)const
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))) {
            overloadId = 0; // IncidenceBase::attendeeByMails(const QStringList&,const QString&=)const->KCalendarCore::Attendee
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "attendeeByMails", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"email", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "attendeeByMails", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);
            }
        }
        ::QStringList cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        ::QString cppArg1 = QString();
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::attendeeByMails(const QStringList&,const QString&=)const->KCalendarCore::Attendee
            KCalendarCore::Attendee cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->attendeeByMails(cppArg0, cppArg1);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_attendeeByUid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::attendeeByUid(const QString&)const->KCalendarCore::Attendee
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // IncidenceBase::attendeeByUid(const QString&)const->KCalendarCore::Attendee
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "attendeeByUid", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::attendeeByUid(const QString&)const->KCalendarCore::Attendee
            KCalendarCore::Attendee cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->attendeeByUid(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Attendee_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_attendeeCount(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::attendeeCount()const->int
        int cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->attendeeCount();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<int>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_attendees(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::attendees()const->QList<KCalendarCore::Attendee>
        QList<KCalendarCore::Attendee> cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->attendees();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_Attendee_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_clearAttendees(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::clearAttendees()
        cppSelf->clearAttendees();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_clearComments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::clearComments()
        cppSelf->clearComments();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_clearContacts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::clearContacts()
        cppSelf->clearContacts();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_comments(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::comments()const->QStringList
        QStringList cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->comments();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_contacts(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::contacts()const->QStringList
        QStringList cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->contacts();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QStringList_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_customPropertyUpdate(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CustomProperties::customPropertyUpdate()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::KCalendarCore::IncidenceBase::customPropertyUpdate()
            : cppSelf->customPropertyUpdate();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_customPropertyUpdated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // CustomProperties::customPropertyUpdated()
        Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? cppSelf->::KCalendarCore::IncidenceBase::customPropertyUpdated()
            : cppSelf->customPropertyUpdated();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_dateTime(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), (pyArg)))) {
        overloadId = 0; // IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "dateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::KCalendarCore::IncidenceBase::DateTimeRole cppArg0{KCalendarCore::IncidenceBase::RoleAlarmStartOffset};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::dateTime(KCalendarCore::IncidenceBase::DateTimeRole)const->QDateTime
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.dateTime");
                return {};
            }
            QDateTime cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->dateTime(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_deserialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::deserialize(QDataStream&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::deserialize(QDataStream&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "deserialize", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDataStream *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::deserialize(QDataStream&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::IncidenceBase::deserialize(*cppArg0)
                : cppSelf->deserialize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_dirtyFields(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::dirtyFields()const->QSet<KCalendarCore::IncidenceBase::Field>
        QSet<KCalendarCore::IncidenceBase::Field> cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->dirtyFields();
        pyResult = Shiboken::Conversions::copyToPython(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QSet_KCalendarCore_IncidenceBase_Field_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_dtStart(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::dtStart()const->QDateTime
        QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->::KCalendarCore::IncidenceBase::dtStart()
            : const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->dtStart();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_duration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::duration()const->KCalendarCore::Duration
        KCalendarCore::Duration cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->duration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Duration_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_endUpdates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::endUpdates()
        cppSelf->endUpdates();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_equals(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "equals", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::IncidenceBase *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::equals(const KCalendarCore::IncidenceBase&)const->bool
            bool cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->::KCalendarCore::IncidenceBase::equals(*cppArg0)
                : const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->equals(*cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_hasDuration(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::hasDuration()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->hasDuration();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_isReadOnly(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::isReadOnly()const->bool
        bool cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->isReadOnly();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_lastModified(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::lastModified()const->QDateTime
        QDateTime cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->lastModified();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_magicSerializationIdentifier([[maybe_unused]] PyObject *self)
{
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // static IncidenceBase::magicSerializationIdentifier()->quint32
        quint32 cppResult = ::KCalendarCore::IncidenceBase::magicSerializationIdentifier();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<quint32>(), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_mimeType(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::mimeType()const->QLatin1String
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.mimeType");
            return {};
        }
        QLatin1String cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->mimeType();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QLatin1String_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_organizer(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::organizer()const->KCalendarCore::Person
        KCalendarCore::Person* cppResult = new KCalendarCore::Person(const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->organizer());
        pyResult = Shiboken::Object::newObject(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), cppResult, true, true);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_recurrenceId(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::recurrenceId()const->QDateTime
        QDateTime cppResult = Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
            ? const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->::KCalendarCore::IncidenceBase::recurrenceId()
            : const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->recurrenceId();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_registerObserver(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::registerObserver(KCalendarCore::IncidenceBase::IncidenceObserver*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::registerObserver(KCalendarCore::IncidenceBase::IncidenceObserver*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "registerObserver", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::IncidenceBase::IncidenceObserver *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::registerObserver(KCalendarCore::IncidenceBase::IncidenceObserver*)
            cppSelf->registerObserver(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_removeComment(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::removeComment(const QString&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // IncidenceBase::removeComment(const QString&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeComment", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::removeComment(const QString&)->bool
            bool cppResult = cppSelf->removeComment(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_removeContact(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::removeContact(const QString&)->bool
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // IncidenceBase::removeContact(const QString&)->bool
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "removeContact", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::removeContact(const QString&)->bool
            bool cppResult = cppSelf->removeContact(cppArg0);
            pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
        }
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_resetDirtyFields(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::resetDirtyFields()
        cppSelf->resetDirtyFields();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_serialize(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::serialize(QDataStream&)const
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDataStream_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::serialize(QDataStream&)const
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "serialize", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDataStream *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::serialize(QDataStream&)const
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->::KCalendarCore::IncidenceBase::serialize(*cppArg0)
                : const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->serialize(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setAllDay(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setAllDay(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setAllDay(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setAllDay", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setAllDay(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::IncidenceBase::setAllDay(cppArg0)
                : cppSelf->setAllDay(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setAttendees(PyObject *self, PyObject *args, [[maybe_unused]] PyObject *kwds)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths
    errInfo.reset(Shiboken::checkInvalidArgumentCount(numArgs, 1, 2));
    if (!errInfo.isNull())
        return Shiboken::returnWrongArguments(args, "setAttendees", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    if (PyArg_ParseTuple(args, "|OO:setAttendees", &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::setAttendees(const QList<KCalendarCore::Attendee>&,bool=)
    if (numArgs >= 1
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QList_KCalendarCore_Attendee_IDX], (pyArgs[0])))) {
        if (numArgs == 1) {
            overloadId = 0; // setAttendees(QList<KCalendarCore::Attendee>,bool)
        } else if (numArgs >= 2
            && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))) {
            overloadId = 0; // IncidenceBase::setAttendees(const QList<KCalendarCore::Attendee>&,bool=)
        }
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setAttendees", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (kwds != nullptr && PyDict_Size(kwds) > 0) {
            static const Shiboken::ArgumentNameIndexMapping mapping[1] = {{"doUpdate", 1}};
            if (!Shiboken::parseKeywordArguments(kwds, mapping, 1, errInfo, pyArgs)
                || (pyArgs[1] != nullptr && !((pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArgs[1])))))) {
                Py_XINCREF(errInfo.object());
                return Shiboken::returnWrongArguments(args, "setAttendees", errInfo, SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);
            }
        }
        ::QList<KCalendarCore::Attendee> cppArg0;
        pythonToCpp[0](pyArgs[0], &cppArg0);
        bool cppArg1 = true;
        if (pythonToCpp[1])
            pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setAttendees(const QList<KCalendarCore::Attendee>&,bool=)
            cppSelf->setAttendees(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setDateTime(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "setDateTime", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX]))), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "setDateTime", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        ::KCalendarCore::IncidenceBase::DateTimeRole cppArg1{KCalendarCore::IncidenceBase::RoleAlarmStartOffset};
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDateTime(const QDateTime&,KCalendarCore::IncidenceBase::DateTimeRole)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.setDateTime");
                return {};
            }
            cppSelf->setDateTime(*cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setDirtyFields(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setDirtyFields(const QSet<KCalendarCore::IncidenceBase::Field>&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkKCalendarCoreTypeConverters[SBK_KCalendarCore_QSet_KCalendarCore_IncidenceBase_Field_IDX], (pyArg)))) {
        overloadId = 0; // IncidenceBase::setDirtyFields(const QSet<KCalendarCore::IncidenceBase::Field>&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDirtyFields", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::QSet<KCalendarCore::IncidenceBase::Field> cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDirtyFields(const QSet<KCalendarCore::IncidenceBase::Field>&)
            cppSelf->setDirtyFields(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setDtStart(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setDtStart(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setDtStart(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDtStart", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDtStart(const QDateTime&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::IncidenceBase::setDtStart(*cppArg0)
                : cppSelf->setDtStart(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setDuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setDuration(const KCalendarCore::Duration&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Duration_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setDuration(const KCalendarCore::Duration&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setDuration", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::Duration cppArg0_local;
        ::KCalendarCore::Duration *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setDuration(const KCalendarCore::Duration&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::IncidenceBase::setDuration(*cppArg0)
                : cppSelf->setDuration(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setFieldDirty(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setFieldDirty(KCalendarCore::IncidenceBase::Field)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_Field_IDX]))), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setFieldDirty(KCalendarCore::IncidenceBase::Field)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setFieldDirty", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::KCalendarCore::IncidenceBase::Field cppArg0{KCalendarCore::IncidenceBase::FieldDtStart};
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setFieldDirty(KCalendarCore::IncidenceBase::Field)
            cppSelf->setFieldDirty(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setHasDuration(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setHasDuration(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setHasDuration(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setHasDuration", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setHasDuration(bool)
            cppSelf->setHasDuration(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setLastModified(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setLastModified(const QDateTime&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QDateTime_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setLastModified(const QDateTime&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setLastModified", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QDateTime cppArg0_local;
        ::QDateTime *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setLastModified(const QDateTime&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::IncidenceBase::setLastModified(*cppArg0)
                : cppSelf->setLastModified(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setOrganizer(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setOrganizer(const KCalendarCore::Person&)
    // 1: IncidenceBase::setOrganizer(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 1; // IncidenceBase::setOrganizer(const QString&)
    } else if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_Person_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setOrganizer(const KCalendarCore::Person&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setOrganizer", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    switch (overloadId) {
        case 0: // setOrganizer(const KCalendarCore::Person &organizer)
        {
            if (!Shiboken::Object::isValid(pyArg))
                return {};
            ::KCalendarCore::Person *cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // IncidenceBase::setOrganizer(const KCalendarCore::Person&)
                cppSelf->setOrganizer(*cppArg0);
            }
            break;
        }
        case 1: // setOrganizer(const QString &organizer)
        {
            ::QString cppArg0;
            pythonToCpp(pyArg, &cppArg0);

            if (Shiboken::Errors::occurred() == nullptr) {
                // IncidenceBase::setOrganizer(const QString&)
                cppSelf->setOrganizer(cppArg0);
            }
            break;
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setReadOnly(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setReadOnly(bool)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setReadOnly(bool)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setReadOnly", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        bool cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setReadOnly(bool)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::IncidenceBase::setReadOnly(cppArg0)
                : cppSelf->setReadOnly(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setUid(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setUid(const QString&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppConversion(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], (pyArg)))) {
        overloadId = 0; // IncidenceBase::setUid(const QString&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUid", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::QString cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setUid(const QString&)
            cppSelf->setUid(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_setUrl(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::setUrl(const QUrl&)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::setUrl(const QUrl&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "setUrl", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::QUrl cppArg0_local;
        ::QUrl *cppArg0 = &cppArg0_local;
        if (pythonToCpp.isValue())
            pythonToCpp(pyArg, &cppArg0_local);
        else
            pythonToCpp(pyArg, &cppArg0);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::setUrl(const QUrl&)
            cppSelf->setUrl(*cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_shiftTimes(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "shiftTimes", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QTimeZone_IDX]), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "shiftTimes", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArgs[0]))
            return {};
        ::QTimeZone cppArg0_local;
        ::QTimeZone *cppArg0 = &cppArg0_local;
        if (pythonToCpp[0].isValue())
            pythonToCpp[0](pyArgs[0], &cppArg0_local);
        else
            pythonToCpp[0](pyArgs[0], &cppArg0);

        if (!Shiboken::Object::isValid(pyArgs[1]))
            return {};
        ::QTimeZone cppArg1_local;
        ::QTimeZone *cppArg1 = &cppArg1_local;
        if (pythonToCpp[1].isValue())
            pythonToCpp[1](pyArgs[1], &cppArg1_local);
        else
            pythonToCpp[1](pyArgs[1], &cppArg1);


        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::shiftTimes(const QTimeZone&,const QTimeZone&)
            Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))
                ? cppSelf->::KCalendarCore::IncidenceBase::shiftTimes(*cppArg0, *cppArg1)
                : cppSelf->shiftTimes(*cppArg0, *cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_startUpdates(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::startUpdates()
        cppSelf->startUpdates();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_type(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::type()const->KCalendarCore::IncidenceBase::IncidenceType
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.type");
            return {};
        }
        KCalendarCore::IncidenceBase::IncidenceType cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->type();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceType_IDX]))), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_typeStr(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::typeStr()const->QByteArray
        if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
            Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.typeStr");
            return {};
        }
        QByteArray cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->typeStr();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QByteArray_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_uid(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::uid()const->QString
        QString cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->uid();
        pyResult = Shiboken::Conversions::copyToPython(SbkPySide6_QtCoreTypeConverters[SBK_QString_IDX], &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_unRegisterObserver(PyObject *self, PyObject *pyArg)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;

    // Overloaded function decisor
    // 0: IncidenceBase::unRegisterObserver(KCalendarCore::IncidenceBase::IncidenceObserver*)
    if ((pythonToCpp = Shiboken::Conversions::pythonToCppPointerConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceObserver_IDX]), (pyArg)))) {
        overloadId = 0; // IncidenceBase::unRegisterObserver(KCalendarCore::IncidenceBase::IncidenceObserver*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(pyArg, "unRegisterObserver", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        if (!Shiboken::Object::isValid(pyArg))
            return {};
        ::KCalendarCore::IncidenceBase::IncidenceObserver *cppArg0;
        pythonToCpp(pyArg, &cppArg0);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::unRegisterObserver(KCalendarCore::IncidenceBase::IncidenceObserver*)
            cppSelf->unRegisterObserver(cppArg0);
        }
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_update(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::update()
        cppSelf->update();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_updated(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::updated()
        cppSelf->updated();
    }

     return Sbk_ReturnFromPython_None();
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_uri(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::uri()const->QUrl
        QUrl cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->uri();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_url(PyObject *self)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    Shiboken::PythonContextMarker pcm;

    // Call function/method
    {

        // IncidenceBase::url()const->QUrl
        QUrl cppResult = const_cast<const ::KCalendarCore::IncidenceBase *>(cppSelf)->url();
        pyResult = Shiboken::Conversions::copyToPython(Shiboken::Module::get(SbkPySide6_QtCoreTypeStructs[SBK_QUrl_IDX]), &cppResult);
    }

    return Sbk_ReturnFromPython_Result(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBaseFunc_virtual_hook(PyObject *self, PyObject *args)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    Shiboken::AutoDecRef errInfo{};
    Shiboken::PythonContextMarker pcm;
    int overloadId = -1;
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp[2];
    const Py_ssize_t numArgs = PyTuple_Size(args);
    SBK_UNUSED(numArgs)
    PyObject *pyArgs[] = {nullptr, nullptr};

    // invalid argument lengths

    if (PyArg_UnpackTuple(args, "virtual_hook", 2, 2, &(pyArgs[0]), &(pyArgs[1])) == 0)
        return {};


    // Overloaded function decisor
    // 0: IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
    if (numArgs == 2
        && (pythonToCpp[0] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Enum::getConverter(reinterpret_cast<SbkEnumType *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_VirtualHook_IDX]))), (pyArgs[0])))
        && (pythonToCpp[1] = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<void *>(), (pyArgs[1])))) {
        overloadId = 0; // IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
    }

    // Function signature not found.
    if (overloadId == -1)
        return Shiboken::returnWrongArguments(args, "virtual_hook", SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]);

    // Call function/method
    {
        ::KCalendarCore::IncidenceBase::VirtualHook cppArg0 = static_cast< ::KCalendarCore::IncidenceBase::VirtualHook>(0);
        pythonToCpp[0](pyArgs[0], &cppArg0);
        void* cppArg1;
        pythonToCpp[1](pyArgs[1], &cppArg1);

        if (Shiboken::Errors::occurred() == nullptr) {
            // IncidenceBase::virtual_hook(KCalendarCore::IncidenceBase::VirtualHook,void*)
            if (Shiboken::Object::hasCppWrapper(reinterpret_cast<SbkObject *>(self))) {
                Shiboken::Errors::setPureVirtualMethodError("IncidenceBase.virtual_hook");
                return {};
            }
            cppSelf->virtual_hook(cppArg0, cppArg1);
        }
    }

     return Sbk_ReturnFromPython_None();
}


static const char *Sbk_KCalendarCore_IncidenceBase_PropertyStrings[] = {
    "allDay::",
    "attendees:",
    "dtStart::",
    "lastModified::",
    "organizer::",
    "uid::",
    "url::",
    nullptr // Sentinel
};

static const char *Sbk_KCalendarCore_IncidenceBase_EnumFlagInfo[] = {
    "DateTimeRole:IntEnum",
    "Field:IntEnum",
    "IncidenceType:IntEnum",
    "VirtualHook:IntEnum",
    nullptr // Sentinel
};

static PyMethodDef Sbk_KCalendarCore_IncidenceBase_methods[] = {
    {"addAttendee", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_addAttendee), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"addComment", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_addComment), METH_O, nullptr},
    {"addContact", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_addContact), METH_O, nullptr},
    {"allDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_allDay), METH_NOARGS, nullptr},
    {"attendeeByMail", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_attendeeByMail), METH_O, nullptr},
    {"attendeeByMails", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_attendeeByMails), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"attendeeByUid", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_attendeeByUid), METH_O, nullptr},
    {"attendeeCount", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_attendeeCount), METH_NOARGS, nullptr},
    {"attendees", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_attendees), METH_NOARGS, nullptr},
    {"clearAttendees", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_clearAttendees), METH_NOARGS, nullptr},
    {"clearComments", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_clearComments), METH_NOARGS, nullptr},
    {"clearContacts", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_clearContacts), METH_NOARGS, nullptr},
    {"comments", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_comments), METH_NOARGS, nullptr},
    {"contacts", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_contacts), METH_NOARGS, nullptr},
    {"customPropertyUpdate", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_customPropertyUpdate), METH_NOARGS, nullptr},
    {"customPropertyUpdated", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_customPropertyUpdated), METH_NOARGS, nullptr},
    {"dateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_dateTime), METH_O, nullptr},
    {"deserialize", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_deserialize), METH_O, nullptr},
    {"dirtyFields", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_dirtyFields), METH_NOARGS, nullptr},
    {"dtStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_dtStart), METH_NOARGS, nullptr},
    {"duration", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_duration), METH_NOARGS, nullptr},
    {"endUpdates", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_endUpdates), METH_NOARGS, nullptr},
    {"equals", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_equals), METH_O, nullptr},
    {"hasDuration", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_hasDuration), METH_NOARGS, nullptr},
    {"isReadOnly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_isReadOnly), METH_NOARGS, nullptr},
    {"lastModified", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_lastModified), METH_NOARGS, nullptr},
    {"magicSerializationIdentifier", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_magicSerializationIdentifier), METH_NOARGS|METH_STATIC, nullptr},
    {"mimeType", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_mimeType), METH_NOARGS, nullptr},
    {"organizer", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_organizer), METH_NOARGS, nullptr},
    {"recurrenceId", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_recurrenceId), METH_NOARGS, nullptr},
    {"registerObserver", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_registerObserver), METH_O, nullptr},
    {"removeComment", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_removeComment), METH_O, nullptr},
    {"removeContact", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_removeContact), METH_O, nullptr},
    {"resetDirtyFields", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_resetDirtyFields), METH_NOARGS, nullptr},
    {"serialize", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_serialize), METH_O, nullptr},
    {"setAllDay", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setAllDay), METH_O, nullptr},
    {"setAttendees", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setAttendees), METH_VARARGS|METH_KEYWORDS, nullptr},
    {"setDateTime", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setDateTime), METH_VARARGS, nullptr},
    {"setDirtyFields", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setDirtyFields), METH_O, nullptr},
    {"setDtStart", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setDtStart), METH_O, nullptr},
    {"setDuration", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setDuration), METH_O, nullptr},
    {"setFieldDirty", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setFieldDirty), METH_O, nullptr},
    {"setHasDuration", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setHasDuration), METH_O, nullptr},
    {"setLastModified", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setLastModified), METH_O, nullptr},
    {"setOrganizer", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setOrganizer), METH_O, nullptr},
    {"setReadOnly", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setReadOnly), METH_O, nullptr},
    {"setUid", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setUid), METH_O, nullptr},
    {"setUrl", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_setUrl), METH_O, nullptr},
    {"shiftTimes", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_shiftTimes), METH_VARARGS, nullptr},
    {"startUpdates", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_startUpdates), METH_NOARGS, nullptr},
    {"type", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_type), METH_NOARGS, nullptr},
    {"typeStr", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_typeStr), METH_NOARGS, nullptr},
    {"uid", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_uid), METH_NOARGS, nullptr},
    {"unRegisterObserver", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_unRegisterObserver), METH_O, nullptr},
    {"update", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_update), METH_NOARGS, nullptr},
    {"updated", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_updated), METH_NOARGS, nullptr},
    {"uri", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_uri), METH_NOARGS, nullptr},
    {"url", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_url), METH_NOARGS, nullptr},
    {"virtual_hook", reinterpret_cast<PyCFunction>(Sbk_KCalendarCore_IncidenceBaseFunc_virtual_hook), METH_VARARGS, nullptr},
    {nullptr, nullptr, 0, nullptr} // Sentinel
};

static int Sbk_KCalendarCore_IncidenceBase_setattro(PyObject *self, PyObject *name, PyObject *value)
{
    PySide::Feature::Select(self);
    if (value != nullptr && PyCallable_Check(value) != 0) {
        auto plain_inst = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
        auto *inst = dynamic_cast<IncidenceBaseWrapper *>(plain_inst);
        if (inst != nullptr)
            inst->resetPyMethodCache();
    }
    return PyObject_GenericSetAttr(self, name, value);
}

// Rich comparison
static PyObject * Sbk_KCalendarCore_IncidenceBase_richcompare(PyObject *self, PyObject *pyArg, int op)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto &cppSelf = *reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    PyObject *pyResult{};
    [[maybe_unused]] Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    switch (op) {
        case Py_NE:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), (pyArg)))) {
                // IncidenceBase::operator!=(const KCalendarCore::IncidenceBase&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::IncidenceBase *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf != (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_True;
                Py_INCREF(pyResult);
            }

            break;
        case Py_EQ:
            if ((pythonToCpp = Shiboken::Conversions::pythonToCppReferenceConversion(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), (pyArg)))) {
                // IncidenceBase::operator==(const KCalendarCore::IncidenceBase&)const->bool
                if (!Shiboken::Object::isValid(pyArg))
                    return {};
                ::KCalendarCore::IncidenceBase *cppArg0;
                pythonToCpp(pyArg, &cppArg0);
                bool cppResult = cppSelf == (*cppArg0);
                pyResult = Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppResult);
            } else {
                pyResult = Py_False;
                Py_INCREF(pyResult);
            }

            break;
        default:
            // PYSIDE-74: By default, we redirect to object's tp_richcompare (which is `==`, `!=`).
            return FallbackRichCompare(self, pyArg, op);
    }

    return Shiboken::returnFromRichCompare(pyResult);
}

static PyObject *Sbk_KCalendarCore_IncidenceBase_get_mReadOnly(PyObject *self, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return {};
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    bool cppOut_local = cppSelf->mReadOnly;
    return Shiboken::Conversions::copyToPython(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), &cppOut_local);
}
static int Sbk_KCalendarCore_IncidenceBase_set_mReadOnly(PyObject *self, PyObject *pyIn, void * /* closure */)
{
    if (!Shiboken::Object::isValid(self))
        return 0;
    [[maybe_unused]] auto *cppSelf = reinterpret_cast< ::KCalendarCore::IncidenceBase *>(Shiboken::Conversions::cppPointer(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX]), reinterpret_cast<SbkObject *>(self)));
    if (pyIn == nullptr) {
        Shiboken::Errors::setInvalidTypeDeletion("mReadOnly");
        return -1;
    }
    Shiboken::Conversions::PythonToCppConversion pythonToCpp;
    if (!(pythonToCpp = Shiboken::Conversions::pythonToCppConversion(Shiboken::Conversions::PrimitiveTypeConverter<bool>(), (pyIn)))) {
        Shiboken::Errors::setSetterTypeError("mReadOnly", "bool");
        return -1;
    }

    auto cppOut_local = cppSelf->mReadOnly;
    pythonToCpp(pyIn, &cppOut_local);
    cppSelf->mReadOnly = cppOut_local;

    return 0;
}

// Getters and Setters for IncidenceBase
static PyGetSetDef Sbk_KCalendarCore_IncidenceBase_getsetlist[] = {
    {"mReadOnly", Sbk_KCalendarCore_IncidenceBase_get_mReadOnly, Sbk_KCalendarCore_IncidenceBase_set_mReadOnly, "bool", nullptr},
    {nullptr, nullptr, nullptr, nullptr, nullptr} // Sentinel
};

} // extern "C"

static int Sbk_KCalendarCore_IncidenceBase_traverse(PyObject *self, visitproc visit, void *arg)
{
    auto traverseProc = reinterpret_cast<traverseproc>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_traverse));
    ;
    return traverseProc(self, visit, arg);
}
static int Sbk_KCalendarCore_IncidenceBase_clear(PyObject *self)
{
    auto clearProc = reinterpret_cast<inquiry>(PyType_GetSlot(SbkObject_TypeF(), Py_tp_clear));
    ;
    return clearProc(self);
}

// Class Definition -----------------------------------------------
extern "C" {

static PyType_Slot Sbk_KCalendarCore_IncidenceBase_slots[] = {
    {Py_tp_base,        nullptr}, // inserted by introduceWrapperType
    {Py_tp_dealloc,     reinterpret_cast<void *>(&SbkDeallocWrapper)},
    {Py_tp_setattro,    reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_setattro)},
    {Py_tp_traverse,    reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_traverse)},
    {Py_tp_clear,       reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_clear)},
    {Py_tp_richcompare, reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_richcompare)},
    {Py_tp_methods,     reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_methods)},
    {Py_tp_getset,      reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_getsetlist)},
    {Py_tp_init,        reinterpret_cast<void *>(Sbk_KCalendarCore_IncidenceBase_Init)},
    {Py_tp_new,         reinterpret_cast<void *>(SbkDummyNew /* PYSIDE-595: Prevent replacement of "0" with base->tp_new. */)},
    {0, nullptr}
};
static PyType_Spec Sbk_KCalendarCore_IncidenceBase_spec = {
    "1:KCalendarCore.KCalendarCore.IncidenceBase",
    sizeof(SbkObject),
    0,
    Py_TPFLAGS_DEFAULT|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC,
    Sbk_KCalendarCore_IncidenceBase_slots
};

} //extern "C"

static void *Sbk_KCalendarCore_IncidenceBase_typeDiscovery([[maybe_unused]] void *cptr, [[maybe_unused]] PyTypeObject *instanceType)
{
    if (instanceType == Shiboken::SbkType< ::KCalendarCore::CustomProperties >())
        return dynamic_cast< ::KCalendarCore::IncidenceBase *>(reinterpret_cast< ::KCalendarCore::CustomProperties *>(cptr));
    return {};
}


// Type conversion functions.

// Python to C++ enum conversion.
static void Enum_PythonToCpp_KCalendarCore_IncidenceBase_IncidenceType(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::IncidenceBase::IncidenceType>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::IncidenceBase::IncidenceType *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_IncidenceBase_IncidenceType_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceType_IDX])))
        return Enum_PythonToCpp_KCalendarCore_IncidenceBase_IncidenceType;
    return {};
}

static PyObject *KCalendarCore_IncidenceBase_IncidenceType_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::IncidenceBase::IncidenceType>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::IncidenceBase::IncidenceType *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_IncidenceBase_DateTimeRole(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::IncidenceBase::DateTimeRole>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::IncidenceBase::DateTimeRole *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_IncidenceBase_DateTimeRole_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX])))
        return Enum_PythonToCpp_KCalendarCore_IncidenceBase_DateTimeRole;
    return {};
}

static PyObject *KCalendarCore_IncidenceBase_DateTimeRole_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::IncidenceBase::DateTimeRole>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::IncidenceBase::DateTimeRole *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_IncidenceBase_Field(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::IncidenceBase::Field>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::IncidenceBase::Field *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_IncidenceBase_Field_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_Field_IDX])))
        return Enum_PythonToCpp_KCalendarCore_IncidenceBase_Field;
    return {};
}

static PyObject *KCalendarCore_IncidenceBase_Field_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::IncidenceBase::Field>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::IncidenceBase::Field *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

static void Enum_PythonToCpp_KCalendarCore_IncidenceBase_VirtualHook(PyObject *pyIn, void *cppOut)
{
    const auto value = static_cast<::KCalendarCore::IncidenceBase::VirtualHook>(Shiboken::Enum::getValue(pyIn));
    *reinterpret_cast<::KCalendarCore::IncidenceBase::VirtualHook *>(cppOut) = value;

}
static PythonToCppFunc is_Enum_PythonToCpp_KCalendarCore_IncidenceBase_VirtualHook_Convertible(PyObject *pyIn)
{
    if (PyObject_TypeCheck(pyIn, Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_VirtualHook_IDX])))
        return Enum_PythonToCpp_KCalendarCore_IncidenceBase_VirtualHook;
    return {};
}

static PyObject *KCalendarCore_IncidenceBase_VirtualHook_CppToPython_Enum(PyTypeObject *pyType, const void *cppIn)
{
    using IntType = std::underlying_type_t<::KCalendarCore::IncidenceBase::VirtualHook>;
    const auto castCppIn = IntType(*reinterpret_cast<const ::KCalendarCore::IncidenceBase::VirtualHook *>(cppIn));
    return Shiboken::Enum::newItem(pyType, castCppIn);

}

// Python to C++ pointer conversion - returns the C++ object of the Python wrapper (keeps object identity).
static void IncidenceBase_PythonToCpp_IncidenceBase_PTR(PyObject *pyIn, void *cppOut)
{
    Shiboken::Conversions::pythonToCppPointer(Sbk_KCalendarCore_IncidenceBase_TypeF(), pyIn, cppOut);
}
static PythonToCppFunc is_IncidenceBase_PythonToCpp_IncidenceBase_PTR_Convertible(PyObject *pyIn)
{
    if (pyIn == Py_None)
        return Shiboken::Conversions::nonePythonToCppNullPtr;
    if (PyObject_TypeCheck(pyIn, Sbk_KCalendarCore_IncidenceBase_TypeF()))
        return IncidenceBase_PythonToCpp_IncidenceBase_PTR;
    return {};
}

// C++ to Python pointer conversion - tries to find the Python wrapper for the C++ object (keeps object identity).
static PyObject *IncidenceBase_PTR_CppToPython_IncidenceBase(const void *cppIn)
{
    auto *pyOut = reinterpret_cast<PyObject *>(Shiboken::BindingManager::instance().retrieveWrapper(cppIn, Sbk_KCalendarCore_IncidenceBase_TypeF()));
    if (pyOut) {
        Py_INCREF(pyOut);
        return pyOut;
    }
    auto *tCppIn = reinterpret_cast<const ::KCalendarCore::IncidenceBase *>(cppIn);
    const char *typeName = typeid(*tCppIn).name();
    return Shiboken::Object::newObjectForPointer(Sbk_KCalendarCore_IncidenceBase_TypeF(), const_cast<void *>(cppIn), false, typeName);

}

// The signatures string for the functions.
// Multiple signatures have their index "n:" in front.
#if PYSIDE6_COMOPT_COMPRESS == 0
static const char *KCalendarCore_IncidenceBase_SignatureStrings[] = {
    "KCalendarCore.KCalendarCore.IncidenceBase.addAttendee(self,attendee:KCalendarCore.KCalendarCore.Attendee,doUpdate:bool=true)",
    "KCalendarCore.KCalendarCore.IncidenceBase.addComment(self,comment:QString)",
    "KCalendarCore.KCalendarCore.IncidenceBase.addContact(self,contact:QString)",
    "KCalendarCore.KCalendarCore.IncidenceBase.allDay(self)->bool",
    "KCalendarCore.KCalendarCore.IncidenceBase.attendeeByMail(self,email:QString)->KCalendarCore.KCalendarCore.Attendee",
    "KCalendarCore.KCalendarCore.IncidenceBase.attendeeByMails(self,emails:QStringList,email:QString=QString())->KCalendarCore.KCalendarCore.Attendee",
    "KCalendarCore.KCalendarCore.IncidenceBase.attendeeByUid(self,uid:QString)->KCalendarCore.KCalendarCore.Attendee",
    "KCalendarCore.KCalendarCore.IncidenceBase.attendeeCount(self)->int",
    "KCalendarCore.KCalendarCore.IncidenceBase.attendees(self)->QList[KCalendarCore.KCalendarCore.Attendee]",
    "KCalendarCore.KCalendarCore.IncidenceBase.clearAttendees(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.clearComments(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.clearContacts(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.comments(self)->QStringList",
    "KCalendarCore.KCalendarCore.IncidenceBase.contacts(self)->QStringList",
    "KCalendarCore.KCalendarCore.IncidenceBase.customPropertyUpdate(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.customPropertyUpdated(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.dateTime(self,role:KCalendarCore.KCalendarCore.IncidenceBase.DateTimeRole)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.IncidenceBase.deserialize(self,in:PySide6.QtCore.QDataStream)",
    "KCalendarCore.KCalendarCore.IncidenceBase.dirtyFields(self)->QSet[KCalendarCore.KCalendarCore.IncidenceBase.Field]",
    "KCalendarCore.KCalendarCore.IncidenceBase.dtStart(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.IncidenceBase.duration(self)->KCalendarCore.KCalendarCore.Duration",
    "KCalendarCore.KCalendarCore.IncidenceBase.endUpdates(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.equals(self,incidenceBase:KCalendarCore.KCalendarCore.IncidenceBase)->bool",
    "KCalendarCore.KCalendarCore.IncidenceBase.hasDuration(self)->bool",
    "KCalendarCore.KCalendarCore.IncidenceBase.isReadOnly(self)->bool",
    "KCalendarCore.KCalendarCore.IncidenceBase.lastModified(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.IncidenceBase.magicSerializationIdentifier()->quint32",
    "KCalendarCore.KCalendarCore.IncidenceBase.mimeType(self)->QLatin1String",
    "KCalendarCore.KCalendarCore.IncidenceBase.organizer(self)->KCalendarCore.KCalendarCore.Person",
    "KCalendarCore.KCalendarCore.IncidenceBase.recurrenceId(self)->PySide6.QtCore.QDateTime",
    "KCalendarCore.KCalendarCore.IncidenceBase.registerObserver(self,observer:KCalendarCore.KCalendarCore.IncidenceBase.IncidenceObserver)",
    "KCalendarCore.KCalendarCore.IncidenceBase.removeComment(self,comment:QString)->bool",
    "KCalendarCore.KCalendarCore.IncidenceBase.removeContact(self,contact:QString)->bool",
    "KCalendarCore.KCalendarCore.IncidenceBase.resetDirtyFields(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.serialize(self,out:PySide6.QtCore.QDataStream)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setAllDay(self,allDay:bool)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setAttendees(self,attendees:QList[KCalendarCore.KCalendarCore.Attendee],doUpdate:bool=true)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setDateTime(self,dateTime:PySide6.QtCore.QDateTime,role:KCalendarCore.KCalendarCore.IncidenceBase.DateTimeRole)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setDirtyFields(self,arg__1:QSet[KCalendarCore.KCalendarCore.IncidenceBase.Field])",
    "KCalendarCore.KCalendarCore.IncidenceBase.setDtStart(self,dtStart:PySide6.QtCore.QDateTime)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setDuration(self,duration:typing.Union[KCalendarCore.KCalendarCore.Duration, int])",
    "KCalendarCore.KCalendarCore.IncidenceBase.setFieldDirty(self,field:KCalendarCore.KCalendarCore.IncidenceBase.Field)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setHasDuration(self,hasDuration:bool)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setLastModified(self,lm:PySide6.QtCore.QDateTime)",
    "1:KCalendarCore.KCalendarCore.IncidenceBase.setOrganizer(self,organizer:KCalendarCore.KCalendarCore.Person)",
    "0:KCalendarCore.KCalendarCore.IncidenceBase.setOrganizer(self,organizer:QString)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setReadOnly(self,readOnly:bool)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setUid(self,uid:QString)",
    "KCalendarCore.KCalendarCore.IncidenceBase.setUrl(self,url:typing.Union[PySide6.QtCore.QUrl, QString])",
    "KCalendarCore.KCalendarCore.IncidenceBase.shiftTimes(self,oldZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization],newZone:typing.Union[PySide6.QtCore.QTimeZone, PySide6.QtCore.QTimeZone.Initialization])",
    "KCalendarCore.KCalendarCore.IncidenceBase.startUpdates(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.type(self)->KCalendarCore.KCalendarCore.IncidenceBase.IncidenceType",
    "KCalendarCore.KCalendarCore.IncidenceBase.typeStr(self)->PySide6.QtCore.QByteArray",
    "KCalendarCore.KCalendarCore.IncidenceBase.uid(self)->QString",
    "KCalendarCore.KCalendarCore.IncidenceBase.unRegisterObserver(self,observer:KCalendarCore.KCalendarCore.IncidenceBase.IncidenceObserver)",
    "KCalendarCore.KCalendarCore.IncidenceBase.update(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.updated(self)",
    "KCalendarCore.KCalendarCore.IncidenceBase.uri(self)->PySide6.QtCore.QUrl",
    "KCalendarCore.KCalendarCore.IncidenceBase.url(self)->PySide6.QtCore.QUrl",
    "KCalendarCore.KCalendarCore.IncidenceBase.virtual_hook(self,id:KCalendarCore.KCalendarCore.IncidenceBase.VirtualHook,data:void)",
    "KCalendarCore.KCalendarCore.IncidenceBase.__ne__(self,ib:KCalendarCore.KCalendarCore.IncidenceBase)->bool",
    "KCalendarCore.KCalendarCore.IncidenceBase.__eq__(self,ib:KCalendarCore.KCalendarCore.IncidenceBase)->bool",
    nullptr}; // Sentinel
#else
static constexpr size_t KCalendarCore_IncidenceBase_SignatureByteSize = 847;
static constexpr uint8_t KCalendarCore_IncidenceBase_SignatureBytes[847] = {
    0x78, 0xda, 0xcd, 0x57, 0x51, 0x4f, 0xdb, 0x30, 0x10, 0x7e, 0xe7, 0x57, 0xf0, 0x48, 0x25, 0x53,
    0x8d, 0x4d, 0xda, 0x43, 0x24, 0x26, 0x95, 0x56, 0x13, 0xa8, 0x20, 0x28, 0x85, 0x3d, 0x0c, 0xa1,
    0xc8, 0x34, 0xd7, 0x62, 0xcd, 0xb1, 0x8b, 0xe3, 0x74, 0xca, 0x7e, 0xfd, 0x2e, 0x89, 0xd3, 0x26,
    0x11, 0xcd, 0x7a, 0xa6, 0x95, 0xf6, 0x04, 0xae, 0x73, 0xdf, 0x77, 0x3e, 0xfb, 0xee, 0xbb, 0x1b,
    0x0f, 0xb9, 0x04, 0x15, 0x71, 0x33, 0xd4, 0x06, 0xfa, 0xe3, 0xc6, 0xea, 0x4a, 0xcd, 0x44, 0x04,
    0x6a, 0x06, 0x17, 0x3c, 0x81, 0x3e, 0x8f, 0xa2, 0x81, 0xb5, 0xb8, 0x0b, 0x70, 0x92, 0x80, 0x9c,
    0x33, 0xee, 0x56, 0xc1, 0xb8, 0x03, 0xa3, 0x32, 0x61, 0x91, 0x7e, 0x5c, 0x46, 0xdc, 0x42, 0xf0,
    0xa2, 0xb5, 0x3c, 0xb7, 0x26, 0x85, 0xde, 0xd1, 0x98, 0x42, 0x3e, 0xd4, 0x71, 0x0c, 0xca, 0x96,
    0xdc, 0xb3, 0x72, 0x11, 0x4c, 0xa6, 0xd6, 0x08, 0xb5, 0x20, 0x43, 0x29, 0xcb, 0x67, 0x6b, 0xa8,
    0x62, 0xe1, 0x05, 0x25, 0xe5, 0x88, 0x67, 0x05, 0x4c, 0xef, 0xf4, 0x5b, 0x7e, 0x30, 0x8a, 0xb1,
    0x8b, 0xcc, 0x45, 0x76, 0xc3, 0x85, 0x2c, 0x7d, 0x81, 0x18, 0xff, 0x5d, 0x7b, 0x72, 0xfa, 0x6d,
    0x97, 0xc8, 0x7a, 0x53, 0x26, 0x35, 0xce, 0xa4, 0x22, 0xbd, 0x16, 0x89, 0x6d, 0xba, 0x71, 0xee,
    0xfe, 0x9e, 0xf4, 0x0e, 0xe9, 0xd0, 0xa3, 0x88, 0x4a, 0x77, 0x52, 0x11, 0x1d, 0x3e, 0x00, 0x43,
    0x9d, 0xba, 0x97, 0x84, 0x1c, 0x42, 0x59, 0x0f, 0x88, 0xa4, 0x32, 0x9f, 0xe4, 0x21, 0x7b, 0xda,
    0xc5, 0xd1, 0x67, 0x02, 0xcd, 0x4c, 0x02, 0x37, 0x83, 0x26, 0x17, 0xd5, 0xdc, 0x65, 0x8c, 0xb7,
    0x75, 0x91, 0x17, 0x1e, 0xd6, 0x0d, 0x5a, 0x0c, 0xd0, 0xe6, 0x65, 0x91, 0x50, 0xea, 0xf4, 0xde,
    0x28, 0x69, 0x62, 0x75, 0x7c, 0x67, 0xf4, 0x12, 0x8c, 0xcd, 0xca, 0x0a, 0x44, 0x3f, 0xd0, 0x3b,
    0x20, 0x11, 0x19, 0x25, 0xb7, 0x7a, 0x10, 0xb1, 0x2b, 0x9e, 0x46, 0xcb, 0xee, 0xc2, 0xd9, 0x34,
    0x1e, 0x39, 0xe3, 0x7b, 0x34, 0xc3, 0x60, 0xdc, 0x65, 0x53, 0xdc, 0xfc, 0xda, 0x9f, 0xd8, 0xe2,
    0xdb, 0x49, 0xb5, 0x4d, 0x71, 0x07, 0x12, 0x30, 0x82, 0x4b, 0xf1, 0xc7, 0x79, 0x24, 0x54, 0xf0,
    0x0e, 0x2c, 0xc7, 0xb0, 0x03, 0x8f, 0x49, 0x07, 0x15, 0x18, 0xa5, 0xef, 0x02, 0x64, 0x54, 0xbb,
    0x3c, 0xe8, 0x4e, 0x91, 0x26, 0x42, 0x61, 0x4c, 0xc9, 0x96, 0xc8, 0x4e, 0x2d, 0x37, 0xeb, 0x8c,
    0xde, 0x47, 0x78, 0x52, 0xc3, 0xad, 0xd0, 0xaa, 0x82, 0xec, 0xb2, 0x1c, 0xb9, 0x6f, 0x09, 0xf0,
    0xf8, 0x7b, 0xf9, 0x8e, 0xe8, 0xe9, 0x05, 0x6f, 0x29, 0xaf, 0x6a, 0xb7, 0xa8, 0xef, 0xec, 0xfe,
    0x9c, 0xe8, 0x62, 0xf5, 0xca, 0x93, 0x51, 0x2b, 0x22, 0x44, 0x04, 0x91, 0xdc, 0x03, 0x8f, 0x6e,
    0x95, 0xf4, 0xd5, 0x4b, 0xc9, 0x13, 0x7b, 0xa3, 0x23, 0x31, 0x17, 0x55, 0xf2, 0xed, 0xe5, 0xa2,
    0x63, 0xbe, 0x10, 0xb3, 0xa9, 0x4b, 0x85, 0xe2, 0x80, 0x57, 0xb8, 0x69, 0x73, 0x1a, 0x73, 0x82,
    0x14, 0x6f, 0x29, 0xea, 0xc3, 0x97, 0xcf, 0x14, 0x44, 0x74, 0xe0, 0x21, 0x5b, 0xc2, 0x46, 0x20,
    0x10, 0x56, 0x9d, 0x95, 0xf5, 0x8b, 0x80, 0xa3, 0xcd, 0x82, 0x2b, 0x4c, 0x4f, 0xb3, 0xcb, 0x1b,
    0xbc, 0x03, 0x93, 0x90, 0x5e, 0xa0, 0x81, 0x59, 0x6a, 0x4c, 0xbe, 0xbc, 0xda, 0x67, 0x38, 0x0d,
    0x2c, 0xb0, 0x42, 0x83, 0xb9, 0x7d, 0xc1, 0xf2, 0xb2, 0x72, 0xbe, 0x33, 0xed, 0x56, 0x84, 0x8a,
    0xb7, 0x5e, 0x55, 0x48, 0x3d, 0x92, 0x17, 0xb1, 0x5e, 0x41, 0x67, 0xc7, 0x48, 0x7e, 0x7f, 0x15,
    0x66, 0x47, 0xeb, 0xe8, 0x81, 0x99, 0x80, 0x1d, 0xb5, 0xeb, 0x25, 0x01, 0xa0, 0x55, 0xc3, 0x75,
    0x6a, 0xf7, 0x54, 0xc4, 0xd1, 0xaf, 0xc1, 0xa6, 0xbb, 0x65, 0x65, 0xa7, 0x5b, 0xf4, 0xee, 0x54,
    0x94, 0x46, 0x0f, 0xb3, 0x1e, 0x1a, 0xb0, 0xe1, 0xdc, 0xbd, 0x6f, 0xfa, 0xe0, 0xf0, 0x90, 0xc7,
    0xb8, 0x21, 0xbe, 0x95, 0x14, 0x07, 0xdb, 0x1e, 0xfc, 0x87, 0xe4, 0x99, 0xe8, 0x59, 0xeb, 0xf6,
    0x19, 0x37, 0x8b, 0x30, 0x3c, 0x0b, 0xbc, 0x24, 0x93, 0xca, 0x5d, 0x93, 0x4d, 0xe6, 0x34, 0x74,
    0x6b, 0x4c, 0xa8, 0xd8, 0x75, 0xb9, 0x60, 0x95, 0x9c, 0x06, 0x36, 0x5b, 0x62, 0xa6, 0xf4, 0x1f,
    0x15, 0x2e, 0x9e, 0x76, 0x11, 0x55, 0x76, 0x8c, 0xf5, 0x97, 0x7a, 0xb0, 0x22, 0x1a, 0x45, 0x64,
    0x4b, 0xfa, 0x79, 0xbe, 0x0e, 0x88, 0xd1, 0x24, 0x72, 0x5e, 0xb6, 0x24, 0x92, 0xd5, 0x34, 0xd3,
    0x27, 0x71, 0xae, 0xdb, 0x7a, 0xc7, 0x64, 0xdc, 0x71, 0x39, 0x67, 0x01, 0x09, 0xfd, 0xb6, 0x21,
    0x2e, 0x6c, 0xad, 0x35, 0xc1, 0xbf, 0x45, 0xa6, 0x77, 0xf4, 0x69, 0x4f, 0x5c, 0x1e, 0x23, 0x37,
    0xc2, 0x35, 0xfa, 0x08, 0x66, 0xdc, 0xca, 0x27, 0xc4, 0xef, 0x0e, 0x9d, 0x44, 0x08, 0xe3, 0x46,
    0xf7, 0xd4, 0xc8, 0xe6, 0xe3, 0x6e, 0x5f, 0x15, 0x7e, 0xc9, 0x8e, 0x1d, 0x09, 0xed, 0x3d, 0xbf,
    0x8a, 0xb9, 0xcd, 0x2f, 0xd9, 0x15, 0x08, 0x2d, 0xa3, 0x9f, 0x5a, 0x41, 0x37, 0x5b, 0xfe, 0x7d,
    0xfe, 0x15, 0x3b, 0xde, 0xb6, 0x83, 0x2c, 0xc2, 0x6e, 0xba, 0x9e, 0x67, 0xa6, 0xe0, 0xf7, 0x21,
    0x70, 0x49, 0x47, 0xcd, 0x2b, 0x90, 0x6f, 0x63, 0x6c, 0x6b, 0x3d, 0x97, 0x47, 0x9f, 0x91, 0xb7,
    0x6c, 0x44, 0x36, 0xbc, 0xcc, 0x6d, 0xad, 0xd3, 0x45, 0x66, 0x61, 0x60, 0x0c, 0xcf, 0x08, 0x90,
    0xa9, 0x88, 0x5a, 0xd3, 0x2e, 0xc5, 0x58, 0xdd, 0xff, 0x17, 0xad, 0x57, 0xea, 0x37, 0x63, 0xa7,
    0x9e, 0x53, 0x75, 0x6a, 0xc4, 0xb6, 0x2b, 0xc0, 0x84, 0x23, 0x01, 0xc9, 0xfd, 0x00, 0xad, 0x50,
    0x76, 0x70, 0x42, 0x0b, 0x5f, 0xb5, 0xfe, 0xe5, 0xa6, 0x34, 0x8a, 0xf4, 0xfc, 0x28, 0xcd, 0x2f,
    0xd1, 0x3a, 0xef, 0x53, 0x78, 0xb0, 0xd2, 0x82, 0x24, 0x45, 0x61, 0xa8, 0x20, 0x0c, 0x1d, 0xf3,
    0xcb, 0x21, 0x87, 0xc2, 0x30, 0x84, 0xb7, 0x8f, 0x30, 0xfd, 0x05, 0xbf, 0x2a, 0x35, 0xaa
};
#endif

PyTypeObject *init_KCalendarCore_IncidenceBase(PyObject *enclosingClass)
{
    auto &typeStruct = SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IDX];
    if (typeStruct.type != nullptr)
        return typeStruct.type;

    auto *base1 = reinterpret_cast<PyObject *>(Shiboken::Module::get(SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_CustomProperties_IDX]));
    Shiboken::AutoDecRef Sbk_KCalendarCore_IncidenceBase_Type_bases(PyTuple_Pack(1, base1));

    PyTypeObject *pyType = Shiboken::ObjectType::introduceWrapperType(
        enclosingClass,
        "IncidenceBase",
        "KCalendarCore::IncidenceBase*",
        &Sbk_KCalendarCore_IncidenceBase_spec,
        &Shiboken::callCppDestructor< KCalendarCore::IncidenceBase >,
        Sbk_KCalendarCore_IncidenceBase_Type_bases.object(),
        Shiboken::ObjectType::WrapperFlags::InnerClass);
#if PYSIDE6_COMOPT_COMPRESS == 0
    InitSignatureStrings(pyType, KCalendarCore_IncidenceBase_SignatureStrings);
#else
    InitSignatureBytes(pyType, KCalendarCore_IncidenceBase_SignatureBytes, KCalendarCore_IncidenceBase_SignatureByteSize);
#endif
    SbkObjectType_SetPropertyStrings(pyType, Sbk_KCalendarCore_IncidenceBase_PropertyStrings);
    typeStruct.type = pyType;

    // Register Converter
    SbkConverter *converter = Shiboken::Conversions::createConverter(pyType,
        IncidenceBase_PythonToCpp_IncidenceBase_PTR,
        is_IncidenceBase_PythonToCpp_IncidenceBase_PTR_Convertible,
        IncidenceBase_PTR_CppToPython_IncidenceBase);

    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase*");
    Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase&");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase*");
    Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase&");
    Shiboken::Conversions::registerConverterName(converter, typeid(::KCalendarCore::IncidenceBase).name());
    Shiboken::Conversions::registerConverterName(converter, typeid(IncidenceBaseWrapper).name());

    Shiboken::ObjectType::setTypeDiscoveryFunctionV2(pyType, &Sbk_KCalendarCore_IncidenceBase_typeDiscovery);

    // Pass the ..._EnumFlagInfo to the class.
    SbkObjectType_SetEnumFlagInfo(pyType, Sbk_KCalendarCore_IncidenceBase_EnumFlagInfo);

    // Initialization of enums.
    Shiboken::AutoDecRef tpDict{};
    [[maybe_unused]] PyTypeObject *EType{};

    // Initialization of enum 'IncidenceType'.
    const char *IncidenceType_Initializer[] = {
        "TypeEvent",
        "TypeTodo",
        "TypeJournal",
        "TypeFreeBusy",
        "TypeUnknown",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t IncidenceType_InitializerValues[] = {
        uint8_t(KCalendarCore::IncidenceBase::IncidenceType::TypeEvent),    //  0x00  0
        uint8_t(KCalendarCore::IncidenceBase::IncidenceType::TypeTodo),     //  0x01  1
        uint8_t(KCalendarCore::IncidenceBase::IncidenceType::TypeJournal),  //  0x02  2
        uint8_t(KCalendarCore::IncidenceBase::IncidenceType::TypeFreeBusy), //  0x03  3
        uint8_t(KCalendarCore::IncidenceBase::IncidenceType::TypeUnknown)   //  0x04  4
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.IncidenceBase.IncidenceType",
        IncidenceType_Initializer, IncidenceType_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_IncidenceType_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::IncidenceBase::IncidenceType'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_IncidenceBase_IncidenceType_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_IncidenceBase_IncidenceType,
            is_Enum_PythonToCpp_KCalendarCore_IncidenceBase_IncidenceType_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase::IncidenceType");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase::IncidenceType");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceType");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'IncidenceType' enum.

    // Initialization of enum 'DateTimeRole'.
    const char *DateTimeRole_Initializer[] = {
        "RoleAlarmStartOffset",
        "RoleAlarmEndOffset",
        "RoleSort",
        "RoleCalendarHashing",
        "RoleStartTimeZone",
        "RoleEndTimeZone",
        "RoleEndRecurrenceBase",
        "RoleEnd",
        "RoleDisplayEnd",
        "RoleAlarm",
        "RoleRecurrenceStart",
        "RoleDisplayStart",
        "RoleDnD",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t DateTimeRole_InitializerValues[] = {
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleAlarmStartOffset),  //  0x00  0
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleAlarmEndOffset),    //  0x01  1
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleSort),              //  0x02  2
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleCalendarHashing),   //  0x03  3
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleStartTimeZone),     //  0x04  4
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleEndTimeZone),       //  0x05  5
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleEndRecurrenceBase), //  0x06  6
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleEnd),               //  0x07  7
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleDisplayEnd),        //  0x08  8
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleAlarm),             //  0x09  9
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleRecurrenceStart),   //  0x0a  10
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleDisplayStart),      //  0x0b  11
        uint8_t(KCalendarCore::IncidenceBase::DateTimeRole::RoleDnD)                //  0x0c  12
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.IncidenceBase.DateTimeRole",
        DateTimeRole_Initializer, DateTimeRole_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_DateTimeRole_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::IncidenceBase::DateTimeRole'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_IncidenceBase_DateTimeRole_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_IncidenceBase_DateTimeRole,
            is_Enum_PythonToCpp_KCalendarCore_IncidenceBase_DateTimeRole_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase::DateTimeRole");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase::DateTimeRole");
        Shiboken::Conversions::registerConverterAlias(converter, "DateTimeRole");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'DateTimeRole' enum.

    // Initialization of enum 'Field'.
    const char *Field_Initializer[] = {
        "FieldDtStart",
        "FieldDtEnd",
        "FieldLastModified",
        "FieldDescription",
        "FieldSummary",
        "FieldLocation",
        "FieldCompleted",
        "FieldPercentComplete",
        "FieldDtDue",
        "FieldCategories",
        "FieldRelatedTo",
        "FieldRecurrence",
        "FieldAttachment",
        "FieldSecrecy",
        "FieldStatus",
        "FieldTransparency",
        "FieldResources",
        "FieldPriority",
        "FieldGeoLatitude",
        "FieldGeoLongitude",
        "FieldRecurrenceId",
        "FieldAlarms",
        "FieldSchedulingId",
        "FieldAttendees",
        "FieldOrganizer",
        "FieldCreated",
        "FieldRevision",
        "FieldDuration",
        "FieldContact",
        "FieldComment",
        "FieldUid",
        "FieldUnknown",
        "FieldUrl",
        "FieldConferences",
        "FieldColor",
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    constexpr uint8_t Field_InitializerValues[] = {
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldDtStart),         //  0x00  0
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldDtEnd),           //  0x01  1
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldLastModified),    //  0x02  2
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldDescription),     //  0x03  3
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldSummary),         //  0x04  4
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldLocation),        //  0x05  5
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldCompleted),       //  0x06  6
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldPercentComplete), //  0x07  7
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldDtDue),           //  0x08  8
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldCategories),      //  0x09  9
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldRelatedTo),       //  0x0a  10
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldRecurrence),      //  0x0b  11
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldAttachment),      //  0x0c  12
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldSecrecy),         //  0x0d  13
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldStatus),          //  0x0e  14
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldTransparency),    //  0x0f  15
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldResources),       //  0x10  16
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldPriority),        //  0x11  17
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldGeoLatitude),     //  0x12  18
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldGeoLongitude),    //  0x13  19
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldRecurrenceId),    //  0x14  20
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldAlarms),          //  0x15  21
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldSchedulingId),    //  0x16  22
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldAttendees),       //  0x17  23
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldOrganizer),       //  0x18  24
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldCreated),         //  0x19  25
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldRevision),        //  0x1a  26
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldDuration),        //  0x1b  27
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldContact),         //  0x1c  28
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldComment),         //  0x1d  29
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldUid),             //  0x1e  30
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldUnknown),         //  0x1f  31
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldUrl),             //  0x20  32
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldConferences),     //  0x21  33
        uint8_t(KCalendarCore::IncidenceBase::Field::FieldColor)            //  0x22  34
        };
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.IncidenceBase.Field",
        Field_Initializer, Field_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_Field_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::IncidenceBase::Field'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_IncidenceBase_Field_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_IncidenceBase_Field,
            is_Enum_PythonToCpp_KCalendarCore_IncidenceBase_Field_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase::Field");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase::Field");
        Shiboken::Conversions::registerConverterAlias(converter, "Field");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'Field' enum.

    // Initialization of enum 'VirtualHook'.
    const char *VirtualHook_Initializer[] = {
        nullptr};
    // "uint8_t" used instead of "unsigned int"
    const uint8_t *VirtualHook_InitializerValues{};
    EType = Shiboken::Enum::createPythonEnum(pyType,
        "1:KCalendarCore.KCalendarCore.IncidenceBase.VirtualHook",
        VirtualHook_Initializer, VirtualHook_InitializerValues);
    SbkKCalendarCoreTypeStructs[SBK_KCalendarCore_IncidenceBase_VirtualHook_IDX].type = EType;
    // Register converter for enum 'KCalendarCore::IncidenceBase::VirtualHook'.
    {
        SbkConverter *converter = Shiboken::Conversions::createConverter(EType,
            KCalendarCore_IncidenceBase_VirtualHook_CppToPython_Enum);
        Shiboken::Conversions::addPythonToCppValueConversion(converter,
            Enum_PythonToCpp_KCalendarCore_IncidenceBase_VirtualHook,
            is_Enum_PythonToCpp_KCalendarCore_IncidenceBase_VirtualHook_Convertible);
        Shiboken::Conversions::registerConverterName(converter, "KCalendarCore::IncidenceBase::VirtualHook");
        Shiboken::Conversions::registerConverterAlias(converter, "IncidenceBase::VirtualHook");
        Shiboken::Conversions::registerConverterAlias(converter, "VirtualHook");
        Shiboken::Enum::setTypeConverter(EType, converter, nullptr);
    }
    // End of 'VirtualHook' enum.

    qRegisterMetaType< ::KCalendarCore::IncidenceBase *>();
    qRegisterMetaType< ::KCalendarCore::IncidenceBase::IncidenceType >("IncidenceBase::IncidenceType");
    qRegisterMetaType< ::KCalendarCore::IncidenceBase::IncidenceType >("KCalendarCore::IncidenceBase::IncidenceType");
    qRegisterMetaType< ::KCalendarCore::IncidenceBase::DateTimeRole >("IncidenceBase::DateTimeRole");
    qRegisterMetaType< ::KCalendarCore::IncidenceBase::DateTimeRole >("KCalendarCore::IncidenceBase::DateTimeRole");
    qRegisterMetaType< ::KCalendarCore::IncidenceBase::Field >("IncidenceBase::Field");
    qRegisterMetaType< ::KCalendarCore::IncidenceBase::Field >("KCalendarCore::IncidenceBase::Field");
    qRegisterMetaType< ::KCalendarCore::IncidenceBase::VirtualHook >("IncidenceBase::VirtualHook");
    qRegisterMetaType< ::KCalendarCore::IncidenceBase::VirtualHook >("KCalendarCore::IncidenceBase::VirtualHook");

    return pyType;
}
